% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{run_tutorial}
\alias{run_tutorial}
\title{Run an interactive tutorial}
\usage{
run_tutorial(name)
}
\arguments{
\item{name}{Tutorial name or number (1-9). Use \code{\link{list_tutorials}}
to see available tutorials.}
}
\value{
No return value, called for the side effect of launching a
\pkg{learnr} tutorial in the browser.
}
\description{
Launches a \pkg{learnr} interactive tutorial in the browser. Students
can type and run code directly in the browser with hints and solutions.
Requires the \pkg{learnr} package.
}
\examples{
if (interactive()) {
  run_tutorial(1)
}

}
\seealso{
\code{\link{open_tutorial}} for the plain Rmd version.
}
